/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** No Commercial Usage
**
** This file contains pre-release code and may not be distributed.
** You may use this file in accordance with the terms and conditions
** contained in the Technology Preview License Agreement accompanying
** this package.
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights.  These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
**
**************************************************************************/

#ifndef DEBUGGER_STACKWINDOW_H
#define DEBUGGER_STACKWINDOW_H

#include <QtGui/QTreeView>

namespace Debugger {
namespace Internal {

class StackWindow : public QTreeView
{
    Q_OBJECT

public:
    explicit StackWindow(QWidget *parent = 0);
    ~StackWindow();

public slots:
    void resizeColumnsToContents();
    void setAlwaysResizeColumnsToContents(bool on);

private slots:
    void rowActivated(const QModelIndex &index);
    void setAlternatingRowColorsHelper(bool on) { setAlternatingRowColors(on); }
    void showAddressColumn(bool on);
    void reloadFullStack();

private:
    void contextMenuEvent(QContextMenuEvent *ev);
    void copyContentsToClipboard();

    void setModelData(int role, const QVariant &value = QVariant(),
        const QModelIndex &index = QModelIndex());
    QVariant modelData(int role, const QModelIndex &index = QModelIndex());

    bool m_alwaysResizeColumnsToContents;
};

} // namespace Internal
} // namespace Debugger

#endif // DEBUGGER_STACKWINDOW_H

